@@ -22,8 +22,14 @@
 /* Define if you support file names longer than 14 characters.  */
 #define SID_HAVE_LONG_FILE_NAMES
 
-/* Define if you have the <strstrea.h> header file.  */
-#undef SID_HAVE_STRSTREA_H
+/* Define if you have the <unistd.h> header file.  */
+#define SID_HAVE_UNISTD_H
+
+/* Define if you have the <sys/stat.h> header file.  */
+#define SID_HAVE_SYS_STAT_H
+
+/* Define if you have the <sys/types.h> header file.  */
+#define SID_HAVE_SYS_TYPES_H
 
 /* Define if you have the strncasecmp function.  */
 #define SID_HAVE_STRNCASECMP
@@ -31,6 +37,12 @@
 /* Define if you have the strcasecmp function.  */
 #define SID_HAVE_STRCASECMP
 
+/* Define if you have the strnicmp function.  */
+#undef SID_HAVE_STRNICMP
+
+/* Define if you have the stricmp function.  */
+#undef SID_HAVE_STRICMP
+
 /* Define if standard member ``ios::binary'' is called ``ios::bin''. */
 #undef SID_HAVE_IOS_BIN
 
